==> SyL-0.9.0.tar.gz: SyL/include/framework/Filter/SyL_FilterFunction.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterFunction.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Filter.php';

/**
 * ѴؿŬѥե륿饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterFunction.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilterFunction extends SyL_Filter
{
    /**
     * ꥯȥѥ᡼δؿŬѤ
     *
     * @access public
     * @param object ꥯȥ֥
     * @param string ؿ̾
     */
    function preAction(&$request, $funcname)
    {
        $parameter =& $request->getParameterObject();
        $parameter->applyParameters($funcname);
    }

    /**
     * ѥ᡼δؿŬѤ
     *
     * @access public
     * @param object ǡޥ͡㥪֥
     * @param string ؿ̾
     */
    function postAction(&$dm, $funcname)
    {
        $parameters =& $dm->getParameters();
        foreach (array_keys($parameters) as $name) {
            $parameters[$name] = $funcname($parameters[$name]);
        }
    }

    /**
     * ɽӥ塼δؿŬѤ
     *
     * @access public
     * @param object ӥ塼֥
     * @param string ؿ̾
     */
    function preRender(&$view, $funcname)
    {
        $render =& $view->getRender();
        $render = $funcname($render);
    }
}

?>

==> SyL-0.11.0.tar.gz: SyL/include/framework/Filter/SyL_FilterFunction.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterFunction.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Filter.php';

/**
 * ѴؿŬѥե륿饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterFunction.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilterFunction extends SyL_Filter
{
    /**
     * ꥯȥѥ᡼δؿŬѤ
     *
     * @access public
     * @param object ꥯȥ֥
     * @param string ؿ̾
     */
    function preAction(&$data, $funcname)
    {
        $data->apply($funcname);
    }

    /**
     * ѥ᡼δؿŬѤ
     *
     * @access public
     * @param object ǡޥ͡㥪֥
     * @param string ؿ̾
     */
    function postAction(&$data, $funcname)
    {
        $this->preAction($data, $funcname);
    }

    /**
     * ɽӥ塼δؿŬѤ
     *
     * @access public
     * @param object ӥ塼֥
     * @param string ؿ̾
     */
    function preRender(&$view, $funcname)
    {
        $render =& $view->getRender();
        $render = $funcname($render);
    }
}

?>
